import 'package:flutter/material.dart';

class StackRouteBuilder {
  StackRouteBuilder({required this.builder, this.maintainState = true, this.onBeforeEnter});

  /// A builder that can inject args into your views before they are built
  final Widget Function(BuildContext context, Map<String, String> args) builder;

  /// Will be called before this route is shown, you can return any substitute route to perform a redirection
  final bool Function(String newRoute)? onBeforeEnter;

  /// Indicates that this route should be cached in memory when it is not on-screen.
  /// This maintains all stateful widgets, textControllers, scrollers etc but consumes more RAM.
  final bool maintainState;
}

extension PathStackRouteExtensions on Widget {
  StackRouteBuilder toStackRoute({bool maintainState = true, bool Function(String newRoute)? onBeforeEnter}) =>
      StackRouteBuilder(builder: (_, __) => this, onBeforeEnter: onBeforeEnter, maintainState: maintainState);
}
